# vim: ts=4 noet sw=4:
#==================================================================================
#	Copyright (c) 2019 Nokia
#	Copyright (c) 2018-2019 AT&T Intellectual Property.
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#==================================================================================

#	Mnemonic:	fmt_changes.ksh
#	Abstract:	This script looks for CHANGES*.txt files at the top level
#				and builds one {X}fm source file from which the release notes
#				RTD file is created.

cat <<endKat

.** ------------------------------------------------------------------------
.** CAUTION: This .xfm file is automatically generated by fmt_changes.ksh
.**          do NOT edit. Use 'make rel-notes.xfm' to regenerate.
.** ------------------------------------------------------------------------

.dv GEN_TITLE 1
.dv doc_title RMR Release Notes
.im setup.im
.dh 1 u=off

&h1(RMR Release Notes)
The following is a list of release highlights for the RMR library.
At one point in time the RMR repo also housed a wrapper library with a
separate version and release cycle.
This resulted in &ital(leap frogging) versions for each package; the
RMR core library was assigned odd major numbers (e.g. 3.1.0).
When the wrapper code was moved to a different repo the need to leap frog
versions ceased, and beginning with version 4.0.0, the RMR versions should
no longer skip.

endKat

for x in ../../../CHANGES*.txt
do
	awk '
		/^#/ { next }		# ditch all comments

		# tag project releases by matching release tag associated
		/4\.4\.6$/  { printf( "&h1(Cherry Release)\n" ); rheader = 1 }
		/4\.0\.5$/  { printf( "&h1(Bronze Release)\n" ); rheader = 1 }
		/1\.11\.1$/ { printf( "&h1(Amber Release)\n" ); rheader = 1 }

		print_raw && /^\t\t/ {			# anything indented should be unformatted
			gsub( "^\t\t", "    ", $0 )
			if( ! format_off ) {
				format_off = 1
				printf( ".nf\n" )
			}
		}

		print_raw && /^$/ {				# include blank lines after first real stuff
			if( format_off ) {
				format_off = 0
				printf( ".fo\n" );
			}
			printf( "&space\n\n" );
			next
		}

		$1 + 0 >= 2019 {
			print_raw = 1				# safe to print blank lines
			printf( "&h2(%s)\n", $0 )
			next
		}

		print_raw { print }
	' $x
done
